@@ -8,7 +8,7 @@ from requests import Response
 # Return response headers, body, and status code
 #
 def pass_on(flow: MitmproxyHTTPFlow, res: Response):
-    if not res:
+    if not isinstance(res, Response):
         return
         
     headers = {}
