@@ -1,3 +1,4 @@
+from .endpoints import EndpointsIndexQueryParams
 from .pagination_query_params import PaginationQueryParams
 from .projects import ProjectCreateParams, ProjectShowResponse, ProjectsIndexQueryParams, ProjectsIndexResponse 
 from .report_show_response import ReportShowResponse
@@ -8,4 +9,6 @@ from .requests_index_query_params import RequestsIndexQueryParams
 from .requests_index_response import RequestsIndexResponse
 from .response_show_response import ResponseShowResponse
 from .scenarios import ScenarioShowResponse, ScenariosIndexResponse
+from .tests import TestCreateParams, TestShowResponse, TestsIndexQueryParams, TestsIndexResponse
+from .traces import TraceShowResponse
 from .users import UserProfileResponse
\ No newline at end of file
